function figures( data, do_print)
%FIGURES plots figures from the example problem for NLFET

close all

if nargin < 2
	do_print = 0;
end

fmt1 = 'k';
if do_print
	fmt2 = 'b-.';
	fmt3 = 'r--';
	print_type = '-dps2';
else
	fmt2 = 'b';
	fmt3 = 'r';
end

count = 1;

figure
plot( data.time(1:data.idx_max), data.Ylinear(:,1), fmt1, ...
	data.timer, data.response(:,1), fmt2);
title( 'Displacement (X) -- Uncontrolled');
legend( 'Linear', 'Nonlinear');
xlabel( 'Time (seconds)');
ylabel( 'Displacement (inches)');

if do_print
	outfile = sprintf( 'output%d', count);
	orient landscape
	print( print_type, outfile);
	count = count + 1;
	close all
end

figure
plot( data.time(1:data.idx_max), data.Ylinear(:,2), fmt1, ...
	data.timer, data.response(:,2), fmt2, ...
	data.timer, data.response(:,7), fmt3);
title( 'Rotation at Node 2 -- Uncontrolled');
legend( 'Linear', 'Nonlinear (at joint)', 'Nonlinear (inside hinge)');
xlabel( 'Time (seconds)');
ylabel( 'Rotation (radians)');

if do_print
	outfile = sprintf( 'output%d', count);
	orient landscape
	print( print_type, outfile);
	count = count + 1;
	close all
end

figure
plot( data.time(1:data.idx_max), data.Ylinear(:,4), fmt1, ...
	data.timer, data.response(:,4), fmt2);
title( 'Velocity (X) -- Uncontrolled');
legend( 'Linear', 'Nonlinear');
xlabel( 'Time (seconds)');
ylabel( 'Velocity (inches/second)');

if do_print
	outfile = sprintf( 'output%d', count);
	orient landscape
	print( print_type, outfile);
	count = count + 1;
	close all
end

figure
plot( data.time(1:data.idx_max), data.Ylinear(:,1), fmt1, ...
	data.time(1:data.idx_max), data.YlinearC(:,1), fmt2);
title( 'Displacement -- Linear Only');
legend( 'Uncontrolled', 'Passive Control');
xlabel( 'Time (seconds)');
ylabel( 'Displacement (inches)');

if do_print
	outfile = sprintf( 'output%d', count);
	orient landscape
	print( print_type, outfile);
	count = count + 1;
	close all
end

figure
plot( data.timer, data.response(:,1), fmt1, data.timeC, data.responseC(:,1), fmt2);
title( 'Displacement -- Nonlinear Only');
legend( 'Uncontrolled', 'Passive Control');
xlabel( 'Time (seconds)');
ylabel( 'Displacement (inches)');

if do_print
	outfile = sprintf( 'output%d', count);
	orient landscape
	print( print_type, outfile);
	count = count + 1;
	close all
end

figure
plot( data.time(1:data.idx_max), data.YlinearC(:,1), fmt1, ...
	data.timeC, data.responseC(:,1), fmt2);
title( 'Displacement (X) -- Passive Control');
legend( 'Linear', 'Nonlinear');
xlabel( 'Time (seconds)');
ylabel( 'Displacement (inches)');

if do_print
	outfile = sprintf( 'output%d', count)
	orient landscape
	print( print_type, outfile);
	count = count + 1;
	close all
end

figure
plot( data.time(1:data.idx_max), data.YlinearC(:,2), fmt1, ...
	data.timeC, data.responseC(:,2), fmt2, ...
	data.timeC, data.responseC(:,7), fmt3);
title( 'Rotation at Node 2 -- Passive Control');
legend( 'Linear', 'Nonlinear (at joint)', 'Nonlinear (inside hinge)');
xlabel( 'Time (seconds)');
ylabel( 'Rotation (radians)');

if do_print
	outfile = sprintf( 'output%d', count);
	orient landscape
	print( print_type, outfile);
	count = count + 1;
	close all
end

figure
plot( data.time(1:data.idx_max), data.YlinearC(:,4), fmt1, ...
	data.timeC, data.responseC(:,4), fmt2);
title( 'Velocity (X) -- Passive Control');
legend( 'Linear', 'Nonlinear');
xlabel( 'Time (seconds)');
ylabel( 'Velocity (inches/second)');

if do_print
	outfile = sprintf( 'output%d', count);
	orient landscape
	print( print_type, outfile);
	count = count + 1;
	close all
end

