 


function varargout = nlodefile(t,y,flag, data)


% Synopsis:
%   nlodefile[_debug][_mass]( t, y, flag, data)
%
% Data is the problem data structure

 switch flag
 case ''                                 % Return dy/dt = f(t,y).
   varargout{1} = f( t, y, data);
 %case 'init'                             % Return default [tspan,y0,options].
   %[varargout{1:3}] = init(p1,p2);
 case 'jacobian'                         % Return Jacobian matrix df/dy.
	disp( flag);
	varargout{1} = data.A;
 case 'jpattern'                          % Return sparsity pattern matrix S.
 % For now, we know that the top half is sparse
	disp( flag);
   varargout{1} = local_pattern( t, y, data);

 %case 'events'                           % Return [value,isterminal,direction].
   %[varargout{1:3}] = events(t,y,p1,p2);
 otherwise
   error(['Unknown flag ''' flag '''.']);
 end
 
 % --------------------------------------------------------------------------

 
function ydotvec = f( t, yvec, data)

	
	% A is sized based on displacements and velocities.  It has nothing to do
	% with the extra state variables from the nonlinear elements.
	ndof  = size(data.A,1) / 2;
	ndof2 = 2*ndof;  % save a few flops

	if size(yvec,2) > 1
		% Vectorized
		ydotvec = zeros(size(yvec));
	end
	ydot = zeros( ndof2+data.num_states,1);  % force this to be a column vector



	a_g = [ interp1( data.time, data.acc_x, t, '*linear')];



	
for count = 1 : size(yvec,2)  % {
	y = yvec(:,count);
	% The linear (easy) part
	 
	
		ydot(1: ndof2) = data.A * y(1: ndof2) + data.Bss * a_g;
	


	% Q is the sum of all the non linear forces

	% TODO: The 6 should not be hard coded
	Q = zeros( 6, 1);


	% The nonlinear (hard) part
	
	% expand out the displacements and velocities
	u = data.T_state * y(1:ndof);
	v = data.T_state * y(ndof+1: ndof2);
	for x = 1 : length( data.nl_el)

		n = data.nl_el(x).num;
		dofvec = data.nl_el(x).dofvec;
		[F,zdot,state] = feval(data.elements(n).type, 'nonlinear-global-force',    ...
			data.elements(n), data.materials(data.elements(n).material),             ...
			data.sections(data.elements(n).section), data.nodelist,                  ...
			u(dofvec), v(dofvec),                                                    ...
			y( ndof2 + data.state_beg(x) : ndof2 + data.state_end(x)),             ...
			data.nl_el(x).data );
		Q(dofvec) = Q(dofvec) + F;

		% Add state derivatives to ydot
		ydot(ndof2 + data.state_beg(x) : ndof2 + data.state_end(x)) = zdot;
		
	end

	% TODO: Check for linear elements that have state variables?






	% Now, add the nonlinear forces to the derivative term

	ydot(ndof+1:ndof2) = ydot(ndof+1:ndof2) - data.invMslab * data.T_state' * Q; %'


	ydotvec(:,count) = ydot;


end % }


 













 
function S = local_pattern( t, y, data);
 	ndof = size(data.A,1) / 2;
	% A is square with dimension ndof*2+data.num_states
	S=ones(ndof*2+data.num_states);
	S(1:ndof,1:2*ndof) = data.A(1:ndof,1:2*ndof);
	S(1:ndof,2*ndof+1:2*ndof+data.num_states) = zeros(ndof,data.num_states);
	S = sparse(S);
 













